@@ -28,4 +28,6 @@ Static Assets
 
 
 def includeme(config):
+    # TODO: Remove edbob.
+    config.include('edbob.pyramid.static')
     config.add_static_view('tailbone', 'tailbone:static')
